@@ -1,16 +1,32 @@
 package MooseX::Workers;
 use Moose::Role;
 use MooseX::Workers::Job;
-our $VERSION = '0.12_02';      # http://www.cpan.org/modules/04pause.html - Developer releases
+our $VERSION = '0.14_01';      # http://www.cpan.org/modules/04pause.html - Developer releases
 
 use MooseX::Workers::Engine;
 
+has _ctor_params => (
+	is => 'ro',
+	isa => 'HashRef',
+	lazy => 1,
+	default => sub { {} },
+);
+
+around BUILDARGS => sub {
+	my ($orig, $class, %args) = @_;
+
+	shift;
+	shift;
+	
+	return $class->$orig( _ctor_params => \%args, @_ );
+};
+
 has Engine => (
     isa      => 'MooseX::Workers::Engine',
     is       => 'ro',
     lazy     => 1,
     required => 1,
-    default  => sub { MooseX::Workers::Engine->new( visitor => $_[0] ) },
+    builder  => '_build_Engine',
     handles  => [
         qw(
           max_workers
@@ -22,6 +38,12 @@ has Engine => (
           )
     ],
 );
+sub _build_Engine {
+	my $self = shift;
+	my @args;
+	push @args,  max_workers => $self->_ctor_params->{max_workers} if exists $self->_ctor_params->{max_workers};
+	MooseX::Workers::Engine->new( visitor => $self, @args );
+}
 
 sub spawn {
     my ( $self, $cmd, $args ) = @_;
